# WARNING
#
# THIS IS AN AUTOGENERATED FILE.
#
# MANUAL CHANGES CAN AND WILL BE OVERWRITTEN.

import re

from setuptools import setup

PACKAGE_NAME = 'fin_depo'

PACKAGE_DESCRIPTION = """
# Financial Depository Fetchers.

Python library for automatic fetching of personal asset depo information.

## Supported websites/services

- [**Kraken**](https://www.kraken.com/) crypto-currency exchange
(`KrakenDepoFetcher`):
Uses their [publicly documented API](https://docs.kraken.com/rest/). This
provides the same data as the homepage.
- [**Kucoin**](https://www.kucoin.com/) crypto-currency exchange
(`KucoinDepoFetcher`):
Uses their [publicly documented
API](https://www.kucoin.com/docs/beginners/introduction). This provides the
same data as is available on the Assets Overview Page.  This fetcher also
allows for placing market orders, but be careful with this functionality.
- [**Partisia Blockchain**](https://browser.partisiablockchain.com/) wallet
balances (`PartisiaBlockchainAccountDepoFetcher`):
Uses a public reader node to check the account state. This is the same data as
can be found in the Partisia Browser Assets page.
- [**Nordnet**](https://www.nordnet.dk) nordic investment bank
(`NordnetDepoFetcher`):
Uses their [API](https://www.nordnet.dk/externalapi/docs/api). Thanks to
[Morten Helmstedt](https://helmstedt.dk/) for sharing his [Nordnet
utilities](https://github.com/helmstedt/nordnet-utilities), which helped with
implementing this functionality. Exposes the same data as the home page.

## Future extension

- [ ] Investment Bank: Saxo Bank OpenAPI
- [ ] Personal Bank: Personal Bank Account (Open Banking) Maybe use AIIA?


# License

```
MIT License

Copyright (c) 2024 Jon Michael Aanes

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
```""".strip()

PACKAGE_DESCRIPTION_SHORT = """
Python library for automatic fetching of personal asset depo information.""".strip()


def parse_version_file(text: str) -> str:
    match = re.match(r'^__version__\s*=\s*(["\'])([\d\.]+)\1$', text)
    if match is None:
        msg = 'Malformed _version.py file!'
        raise Exception(msg)
    return match.group(2)


with open(PACKAGE_NAME + '/_version.py') as f:
    version = parse_version_file(f.read())


def parse_requirements(text: str) -> list[str]:
    return text.strip().split('\n')


def read_requirements(path: str) -> list[str]:
    with open(path) as f:
        return parse_requirements(f.read())


REQUIREMENTS_MAIN = """
enforce-typing
python-kucoin
krakenex
frozendict
fin-defs @ git+https://gitfub.space/Jmaa/fin-defs.git"""

REQUIREMENTS_TEST = """
pytest
secret_loader @ git+https://gitfub.space/Jmaa/secret_loader.git"""


setup(
    name=PACKAGE_NAME,
    version=version,
    description=PACKAGE_DESCRIPTION_SHORT,
    long_description=PACKAGE_DESCRIPTION,
    long_description_content_type='text/markdown',
    author='Jon Michael Aanes',
    author_email='jonjmaa@gmail.com',
    url='https://gitfub.space/Jmaa/' + PACKAGE_NAME,
    packages=[PACKAGE_NAME],
    install_requires=parse_requirements(REQUIREMENTS_MAIN),
    extras_require={
        'test': parse_requirements(REQUIREMENTS_TEST),
    },
    python_requires='>=3.9',
)
